import java.util.ArrayList;
import java.util.List;

import javax.faces.model.DataModel;

import org.ajax4jsf.model.ExtendedDataModel;
import org.richfaces.model.DataProvider;
import org.richfaces.model.ExtendedTableDataModel;
import org.richfaces.model.ModifiableModel;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import ch.vd.institutions.votelec.controller.datamodel.ModifiableExtendedDataModel;
import ch.vd.institutions.votelec.controller.datamodel.MyFilterField;
import ch.vd.institutions.votelec.controller.datamodel.MySortField;
import ch.vd.institutions.votelec.controller.datamodel.dataprovider.SortableFilterableDataProvider;
import ch.vd.institutions.votelec.controller.datamodel.dataprovider.impl.Price;

@Component("testController")
@Scope("request")
public class TestController {
	private static final int NUMBER_MAX = 500;

	// GET MY DATAMODEL
	public DataModel getItemsMyDataModel(){
		// Define a dataProvider
		SortableFilterableDataProvider<Price, ColumnEnum> dataProvider = new SortableFilterableDataProvider<Price, ColumnEnum>() {

			public List<Price> getItemsByRange(int firstRow, int lastRow, List<MyFilterField<ColumnEnum>> filterFields, List<MySortField<ColumnEnum>> sortFields) {
				return generateItems(firstRow, lastRow);
			}

			public int getRowCount() {
				return NUMBER_MAX;
			}

			public ColumnEnum convertColumnEnum(String columnName) {
				return ColumnEnum.valueOf(columnName);
			}
		};

		return new ModifiableExtendedDataModel<Price, ColumnEnum>(dataProvider);
	}

	// GET EXTENDED DATA TABLE MODEL
	public DataModel getItemsExtendedTableDataModel(){
		// Define a dataProvider
		DataProvider<Price> dataProvider = new DataProvider<Price>() {

			public List<Price> getItemsByRange(int firstRow, int lastRow) {
				return generateItems(firstRow, lastRow);
			}

			public int getRowCount() {
				return NUMBER_MAX;
			}

			public Price getItemByKey(Object key) {
				return new Price("Price #" + key, (Integer)key);
			}

			public Object getKey(Price item) {
				return item.getRank();
			}

		};

		return new ExtendedTableDataModel<Price>(dataProvider);
	}

	// GET MODIFIABLE DATA MODEL
	public DataModel getItemsModifiableDataModel(){
		// Define a dataProvider
		DataProvider<Price> dataProvider = new DataProvider<Price>() {

			public List<Price> getItemsByRange(int firstRow, int lastRow) {
				return generateItems(firstRow, lastRow);
			}

			public int getRowCount() {
				return NUMBER_MAX;
			}

			public Price getItemByKey(Object key) {
				return new Price("Price #" + key, (Integer)key);
			}

			public Object getKey(Price item) {
				return item.getRank();
			}

		};

		ExtendedDataModel originalModel = new ExtendedTableDataModel<Price>(dataProvider);

		return new ModifiableModel(originalModel, "item");
	}
	
	// GET LIST
	public List<Price> getItems(){
		return generateItems(0, NUMBER_MAX);
	}

	// ACTION
	public void edit(){
		System.out.println("!! EDIT !!");
	}

	// UTILILITY METHOD - GENERATE ITEMS
	private static List<Price> generateItems(int firstRow, int lastRow){
		List<Price> prices = new ArrayList<Price>();

		for(int i = firstRow; i < lastRow; i++){
			prices.add(new Price("Price #" + i, i));
		}
		return prices;
	}

	// COLUMN ENUM
	enum ColumnEnum {
		COL1, 
		COL2;
	}
}



